==> nipper-0.10.4.tgz: nipper-0.10.4/NMP/report-passwords.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void output_NMPTablePasswords(struct nipperConfig *nipper, int dictPassword)
{
	// Variables
	struct snmpNMPCommunity *communityNMPPointer;
	struct snmpNMPHost *snmpNMPHostPointer;
	char tempString[nipper->maxSize];

	// Table Pointers
	const char *tablerow_start;
	const char *tablerow_mid;
	const char *tablerow_end;
	switch (nipper->outputFormat)
	{
		case output_html:
			tablerow_start = table_html_rowstart;
			tablerow_mid = table_html_rowmid;
			tablerow_end = table_html_rowend;
			break;
		case output_xml:
			tablerow_start = table_xml_rowstart;
			tablerow_mid = table_xml_rowmid;
			tablerow_end = table_xml_rowend;
			break;
		case output_text:
			tablerow_start = table_text_rowstart;
			tablerow_mid = table_text_rowmid;
			tablerow_end = table_text_rowend;
			break;
		case output_latex:
			tablerow_start = table_latex_rowstart;
			tablerow_mid = table_latex_rowmid;
			tablerow_end = table_latex_rowend;
			break;
	}

	// SNMP
	if (nipper->nmp->snmp != 0)
	{
		communityNMPPointer = nipper->nmp->snmp->community;
		while (communityNMPPointer != 0)
		{
			if (((communityNMPPointer->dictionary == true) && (dictPassword == true)) || ((communityNMPPointer->weak == true) && (dictPassword == false)))
			{
				fprintf(nipper->reportFile, "%sCommunity%sSNMP%s(", tablerow_start, tablerow_mid, tablerow_mid);
				if (communityNMPPointer->access == snmp_nmp_readonly)
					fprintf(nipper->reportFile, "read-only");
				else if (communityNMPPointer->access == snmp_nmp_readwrite)
					fprintf(nipper->reportFile, "read-write");
				else
					fprintf(nipper->reportFile, "read-write all");
				if (nipper->passwords == true)
				{
					outputFriendly(communityNMPPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, ")%s%s%s", tablerow_mid, tempString, tablerow_end);
				}
				else
					fprintf(nipper->reportFile, ")%s", tablerow_end);
			}
			communityNMPPointer = communityNMPPointer->next;
		}
		snmpNMPHostPointer = nipper->nmp->snmp->host;
		while (snmpNMPHostPointer != 0)
		{
			if (((snmpNMPHostPointer->dictionary == true) && (dictPassword == true)) || ((snmpNMPHostPointer->weak == true) && (dictPassword == false)))
			{
				outputFriendly(snmpNMPHostPointer->host, tempString, nipper->maxSize, nipper->outputFormat);
				fprintf(nipper->reportFile, "%sCommunity%sSNMP%sHost: %s", tablerow_start, tablerow_mid, tablerow_mid, tempString);
				if (nipper->passwords == true)
				{
					outputFriendly(snmpNMPHostPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s%s%s", tablerow_mid, tempString, tablerow_end);
				}
				else
					fprintf(nipper->reportFile, "%s", tablerow_end);
			}
			snmpNMPHostPointer = snmpNMPHostPointer->next;
		}
	}
}


void output_NMPLinePasswords(struct nipperConfig *nipper, int dictPassword)
{
	// Variables
	struct snmpNMPCommunity *communityNMPPointer;
	struct snmpNMPHost *snmpNMPHostPointer;
	char tempString[nipper->maxSize];

	if (nipper->nmp->snmp != 0)
	{
		communityNMPPointer = nipper->nmp->snmp->community;
		while (communityNMPPointer != 0)
		{
			if (((communityNMPPointer->dictionary == true) && (dictPassword == true)) || ((communityNMPPointer->weak == true) && (dictPassword == false)))
			{
				fprintf(nipper->reportFile, "The ");
				if (communityNMPPointer->access == snmp_nmp_readonly)
					fprintf(nipper->reportFile, "read-only");
				else if (communityNMPPointer->access == snmp_nmp_readwrite)
					fprintf(nipper->reportFile, "read-write");
				else
					fprintf(nipper->reportFile, "read-write all");
				fprintf(nipper->reportFile, " SNMP community string was ");
				if (nipper->passwords == true)
				{
					outputFriendly(communityNMPPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s.", tempString);
				}
				else
				{
					if (dictPassword == true)
						fprintf(nipper->reportFile, "dictionary-based.");
					else
						fprintf(nipper->reportFile, "weak.");
				}
			}
			communityNMPPointer = communityNMPPointer->next;
		}
		snmpNMPHostPointer = nipper->nmp->snmp->host;
		while (snmpNMPHostPointer != 0)
		{
			if (snmpNMPHostPointer->dictionary == true)
			{
				outputFriendly(snmpNMPHostPointer->host, tempString, nipper->maxSize, nipper->outputFormat);
				fprintf(nipper->reportFile, "The SNMP community string for the host %s was ", tempString);
				if (nipper->passwords == true)
				{
					outputFriendly(snmpNMPHostPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s.", tempString);
				}
				else
				{
					if (dictPassword == true)
						fprintf(nipper->reportFile, "dictionary-based.");
					else
						fprintf(nipper->reportFile, "weak.");
				}
			}
			snmpNMPHostPointer = snmpNMPHostPointer->next;
		}
	}
	output_newPara(nipper);
}

==> nipper-0.10.5.tgz: nipper-0.10.5/NMP/report-passwords.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void output_NMPTablePasswords(struct nipperConfig *nipper, int dictPassword)
{
	// Variables
	struct snmpNMPCommunity *communityNMPPointer = 0;
	struct snmpNMPHost *snmpNMPHostPointer = 0;
	char tempString[nipper->maxSize];

	// Table Pointers
	const char *tablerow_start;
	const char *tablerow_mid;
	const char *tablerow_end;
	switch (nipper->outputFormat)
	{
		case output_html:
			tablerow_start = table_html_rowstart;
			tablerow_mid = table_html_rowmid;
			tablerow_end = table_html_rowend;
			break;
		case output_xml:
			tablerow_start = table_xml_rowstart;
			tablerow_mid = table_xml_rowmid;
			tablerow_end = table_xml_rowend;
			break;
		case output_text:
			tablerow_start = table_text_rowstart;
			tablerow_mid = table_text_rowmid;
			tablerow_end = table_text_rowend;
			break;
		case output_latex:
			tablerow_start = table_latex_rowstart;
			tablerow_mid = table_latex_rowmid;
			tablerow_end = table_latex_rowend;
			break;
	}

	// SNMP
	if (nipper->nmp->snmp != 0)
	{
		communityNMPPointer = nipper->nmp->snmp->community;
		while (communityNMPPointer != 0)
		{
			if (((communityNMPPointer->dictionary == true) && (dictPassword == true)) || ((communityNMPPointer->weak == true) && (dictPassword == false)))
			{
				fprintf(nipper->reportFile, "%sCommunity%sSNMP%s(", tablerow_start, tablerow_mid, tablerow_mid);
				if (communityNMPPointer->access == snmp_nmp_readonly)
					fprintf(nipper->reportFile, "read-only");
				else if (communityNMPPointer->access == snmp_nmp_readwrite)
					fprintf(nipper->reportFile, "read-write");
				else
					fprintf(nipper->reportFile, "read-write all");
				if (nipper->passwords == true)
				{
					outputFriendly(communityNMPPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, ")%s%s%s", tablerow_mid, tempString, tablerow_end);
				}
				else
					fprintf(nipper->reportFile, ")%s", tablerow_end);
			}
			communityNMPPointer = communityNMPPointer->next;
		}
		snmpNMPHostPointer = nipper->nmp->snmp->host;
		while (snmpNMPHostPointer != 0)
		{
			if (((snmpNMPHostPointer->dictionary == true) && (dictPassword == true)) || ((snmpNMPHostPointer->weak == true) && (dictPassword == false)))
			{
				outputFriendly(snmpNMPHostPointer->host, tempString, nipper->maxSize, nipper->outputFormat);
				fprintf(nipper->reportFile, "%sCommunity%sSNMP%sHost: %s", tablerow_start, tablerow_mid, tablerow_mid, tempString);
				if (nipper->passwords == true)
				{
					outputFriendly(snmpNMPHostPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s%s%s", tablerow_mid, tempString, tablerow_end);
				}
				else
					fprintf(nipper->reportFile, "%s", tablerow_end);
			}
			snmpNMPHostPointer = snmpNMPHostPointer->next;
		}
	}
}


void output_NMPLinePasswords(struct nipperConfig *nipper, int dictPassword)
{
	// Variables
	struct snmpNMPCommunity *communityNMPPointer = 0;
	struct snmpNMPHost *snmpNMPHostPointer = 0;
	char tempString[nipper->maxSize];

	if (nipper->nmp->snmp != 0)
	{
		communityNMPPointer = nipper->nmp->snmp->community;
		while (communityNMPPointer != 0)
		{
			if (((communityNMPPointer->dictionary == true) && (dictPassword == true)) || ((communityNMPPointer->weak == true) && (dictPassword == false)))
			{
				fprintf(nipper->reportFile, "The ");
				if (communityNMPPointer->access == snmp_nmp_readonly)
					fprintf(nipper->reportFile, "read-only");
				else if (communityNMPPointer->access == snmp_nmp_readwrite)
					fprintf(nipper->reportFile, "read-write");
				else
					fprintf(nipper->reportFile, "read-write all");
				fprintf(nipper->reportFile, " SNMP community string was ");
				if (nipper->passwords == true)
				{
					outputFriendly(communityNMPPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s.", tempString);
				}
				else
				{
					if (dictPassword == true)
						fprintf(nipper->reportFile, "dictionary-based.");
					else
						fprintf(nipper->reportFile, "weak.");
				}
			}
			communityNMPPointer = communityNMPPointer->next;
		}
		snmpNMPHostPointer = nipper->nmp->snmp->host;
		while (snmpNMPHostPointer != 0)
		{
			if (snmpNMPHostPointer->dictionary == true)
			{
				outputFriendly(snmpNMPHostPointer->host, tempString, nipper->maxSize, nipper->outputFormat);
				fprintf(nipper->reportFile, "The SNMP community string for the host %s was ", tempString);
				if (nipper->passwords == true)
				{
					outputFriendly(snmpNMPHostPointer->community, tempString, nipper->maxSize, nipper->outputFormat);
					fprintf(nipper->reportFile, "%s.", tempString);
				}
				else
				{
					if (dictPassword == true)
						fprintf(nipper->reportFile, "dictionary-based.");
					else
						fprintf(nipper->reportFile, "weak.");
				}
			}
			snmpNMPHostPointer = snmpNMPHostPointer->next;
		}
	}
	output_newPara(nipper);
}
